﻿using System.Net.NetworkInformation;

namespace DeviceManagement.ViewModels;

public partial class DeviceManagerViewModel : ObservableObject
{
    public DeviceManagerViewModel(DeviceCollection deviceCollection, IDialogService dialogService)
    {
        this.DeviceCollection = deviceCollection;
        this._DialogService = dialogService;
        FakeData();
    }
    void FakeData()
    {
        DeviceCollection.Devices ??= [];
        DeviceCollection.Devices[DeviceModel.JetKepler] = [];
        for (int i = 1; i <= 6; i++)
        {
            DeviceInfo_VM device = new()
            {
                DeviceModel = DeviceModel.JetKepler,
                DeviceSubModel = KeplerSubModel.JetKepler_2200A.ToString(),
                DeviceName = $"Device {i}",
                Position = $"position-{i}",
                SoftwareVersion = "1.0.0.0",
                Guid = Guid.NewGuid(),
                UpdateTime = DateTime.Now,
            };

            DeviceCollection.Devices[DeviceModel.JetKepler].Add(device);
        }

        DeviceCollection.Devices[DeviceModel.Proxima] = [];

        for (int i = 1; i <= 3; i++)
        {
            DeviceInfo_VM device = new()
            {
                DeviceModel = DeviceModel.Proxima,
                DeviceSubModel = ProximaSubModel.Proxima_ELK.ToString(),
                DeviceName = $"Device {i}",
                Position = $"position-{i}",
                SoftwareVersion = "1.0.0.0",
                Guid = Guid.NewGuid(),
                UpdateTime = DateTime.Now,
            };

            DeviceCollection.Devices[DeviceModel.Proxima].Add(device);
        }

    }

    private readonly IDialogService _DialogService;

    [ObservableProperty]
    private DeviceCollection _DeviceCollection;


    [RelayCommand]
    private void CheckDetail(DeviceInfo_VM deviceInfo)
    {

    }

    [RelayCommand]
    private void Delete(DeviceInfo_VM deviceInfo)
    {
        MessageBoxResult result = MessageBox.Show($"确认删除 {deviceInfo.DeviceModel}-{deviceInfo.DeviceName} ?", "确认删除", MessageBoxButton.YesNo, MessageBoxImage.Question);
        if (result != MessageBoxResult.Yes)
            return;

        this.DeviceCollection.Devices[deviceInfo.DeviceModel].Remove(deviceInfo);
        MessageBox.Show($"{deviceInfo.DeviceModel}-{deviceInfo.DeviceName} 已删除");
    }

    [RelayCommand]
    private void Setting(DeviceInfo_VM deviceInfo)
    {
        IDialogParameters para = new DialogParameters() { { "Device", deviceInfo } };

        this._DialogService.Show("EditDevice", para, null);
    }
}
