﻿using Mapster;

namespace DeviceManagement.ViewModels.Dialog;

internal partial class EditDeviceViewModel(DeviceCollection deviceCollection) : ObservableObject, IDialogAware
{
    public DialogCloseListener RequestClose { get; set; }
    [ObservableProperty]
    private DeviceInfo_VM? _TempDevice;
    public bool CanCloseDialog()
    {
        return true;
    }

    public void OnDialogClosed()
    {

    }

    public void OnDialogOpened(IDialogParameters parameters)
    {
        if (!parameters.TryGetValue<DeviceInfo_VM>("Device", out DeviceInfo_VM? device) || device is null)
        {
            this.RequestClose.Invoke();
            return;
        }
        this.TempDevice = new();
        device.Adapt(this.TempDevice);
    }

    [RelayCommand]
    private void SaveDevice()
    {
        if (this.TempDevice is null)
        {
            MessageBox.Show("Error");
            return;
        }

        if (!deviceCollection.Devices.TryGetValue(this.TempDevice.DeviceModel, out var devices) || devices is null)
        {
            MessageBox.Show("Error");
            return;
        }

        if (devices.Where(t => t.Guid == this.TempDevice.Guid).First() is not DeviceInfo_VM device)
        {
            MessageBox.Show("设备不存在");
            return;
        }
        this.TempDevice.Adapt(device);
        MessageBox.Show("设备信息修改成功！", "设备信息", MessageBoxButton.OK, MessageBoxImage.Information);
        this.RequestClose.Invoke();

    }

    [RelayCommand]
    private void Close()
    {
        this.RequestClose.Invoke();
    }
}
