﻿namespace DeviceScanner.ViewModels.Dialogs;

internal partial class CreateDeviceViewModel(DeviceCollection deviceCollection) : ObservableObject, IDialogAware
{
    [ObservableProperty]
    private DeviceInfo_VM? _TempDevice;
    public DialogCloseListener RequestClose { get; set; }

    public bool CanCloseDialog()
    {
        return true;
    }

    public void OnDialogClosed()
    {
    }

    public void OnDialogOpened(IDialogParameters parameters)
    {
        if (!parameters.TryGetValue<DeviceInfo_VM>("Device", out DeviceInfo_VM? device) || device is null)
        {
            this.RequestClose.Invoke();
            return;
        }

        this.TempDevice = device;

    }

    [RelayCommand]
    private void SaveDevice()
    {
        if (this.TempDevice is null)
            return;
        if (!deviceCollection.Devices.TryGetValue(this.TempDevice.DeviceModel, out ObservableCollection<DeviceInfo_VM>? devices) || devices is null)
            return;

        if (devices.Where(t => t.DeviceName == this.TempDevice.DeviceName).Any())
        {
            MessageBox.Show($"Device Name \"{this.TempDevice.DeviceName}\" already exist", "Warning", MessageBoxButton.OK, MessageBoxImage.Error);
            return;
        }
        if (devices.Where(t => t.IP == this.TempDevice.IP).Any())
        {
            MessageBox.Show($"IP Address \"{this.TempDevice.IP}\" already exist", "Warning", MessageBoxButton.OK, MessageBoxImage.Error);
            return;
        }

        if (string.IsNullOrEmpty(this.TempDevice.DeviceName))
        {
            MessageBox.Show("设备未命名", "Warning", MessageBoxButton.OK, MessageBoxImage.Warning);
            return;
        }

        MessageBoxResult result = MessageBox.Show($"确认添加 {this.TempDevice.DeviceModel}-{this.TempDevice.DeviceName} 设备？", "添加设备", MessageBoxButton.YesNo, MessageBoxImage.Question);

        if (result != MessageBoxResult.Yes)
            return;
        MessageBox.Show("设备添加成功！", "Info", MessageBoxButton.OK, MessageBoxImage.Information);
        this.TempDevice.Guid = Guid.NewGuid();
        devices.Add(this.TempDevice);
        this.RequestClose.Invoke();
    }

    [RelayCommand]
    private void Close()
    {
        this.RequestClose.Invoke();
    }
}
